@@ -6,18 +6,18 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class BspwmProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("Bspwm", ProfileType.WindowMgr)
+		super().__init__('Bspwm', ProfileType.WindowMgr)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		# return super().packages + [
 		return [
-			"bspwm",
-			"sxhkd",
-			"dmenu",
-			"xdo",
-			"rxvt-unicode",
+			'bspwm',
+			'sxhkd',
+			'dmenu',
+			'xdo',
+			'rxvt-unicode',
 		]
 
 	@property
