@@ -9,14 +9,14 @@ if TYPE_CHECKING:
 
 class TailoredProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("52-54-00-12-34-56", ProfileType.Tailored)
+		super().__init__('52-54-00-12-34-56', ProfileType.Tailored)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
-		return ["nano", "wget", "git"]
+		return ['nano', 'wget', 'git']
 
 	@override
-	def install(self, install_session: "Installer") -> None:
+	def install(self, install_session: 'Installer') -> None:
 		super().install(install_session)
 		# do whatever you like here :)
