@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import math
 import time
 from pathlib import Path
 
@@ -8,7 +9,7 @@ from archinstall.tui.curses_menu import Tui
 
 from ..interactions.general_conf import ask_abort
 from ..luks import Luks2
-from ..models.device_model import (
+from ..models.device import (
 	DiskEncryption,
 	DiskLayoutConfiguration,
 	DiskLayoutType,
@@ -42,10 +43,8 @@ class FilesystemHandler:
 			debug('No modifications required')
 			return
 
-		device_paths = ', '.join([str(mod.device.device_info.path) for mod in device_mods])
-
 		if show_countdown:
-			self._final_warning(device_paths)
+			self._final_warning()
 
 		# Setup the blockdevice, filesystem (and optionally encryption).
 		# Once that's done, we'll hand over to perform_installation()
@@ -63,18 +62,12 @@ class FilesystemHandler:
 			for mod in device_mods:
 				if boot_part := mod.get_boot_partition():
 					debug(f'Formatting boot partition: {boot_part.dev_path}')
-					self._format_partitions(
-						[boot_part],
-						mod.device_path,
-					)
+					self._format_partitions([boot_part])
 
 			self.perform_lvm_operations()
 		else:
 			for mod in device_mods:
-				self._format_partitions(
-					mod.partitions,
-					mod.device_path,
-				)
+				self._format_partitions(mod.partitions)
 
 				for part_mod in mod.partitions:
 					if part_mod.fs_type == FilesystemType.Btrfs and part_mod.is_create_or_modify():
@@ -83,7 +76,6 @@ class FilesystemHandler:
 	def _format_partitions(
 		self,
 		partitions: list[PartitionModification],
-		device_path: Path,
 	) -> None:
 		"""
 		Format can be given an overriding path, for instance /dev/null to test
@@ -202,7 +194,15 @@ class FilesystemHandler:
 			desired_size = sum([vol.length for vol in vg.volumes], Size(0, Unit.B, SectorSize.default()))
 
 			delta = desired_size - avail_size
-			max_vol_offset = delta.convert(Unit.B)
+			delta_bytes = delta.convert(Unit.B)
+
+			# Round the offset up to the next physical extent (PE, 4 MiB by default)
+			# to ensure lvcreate`s internal rounding doesn`t consume space reserved
+			# for subsequent logical volumes.
+			pe_bytes = Size(4, Unit.MiB, SectorSize.default()).convert(Unit.B)
+			pe_count = math.ceil(delta_bytes.value / pe_bytes.value)
+			rounded_offset = pe_count * pe_bytes.value
+			max_vol_offset = Size(rounded_offset, Unit.B, SectorSize.default())
 
 			max_vol = max(vg.volumes, key=lambda x: x.length)
 
@@ -285,6 +285,7 @@ class FilesystemHandler:
 					vol.mapper_name,
 					enc_config.encryption_password,
 					lock_after_create,
+					iter_time=enc_config.iter_time,
 				)
 
 				enc_vols[vol] = luks_handler
@@ -315,6 +316,7 @@ class FilesystemHandler:
 						part_mod.mapper_name,
 						enc_config.encryption_password,
 						lock_after_create=lock_after_create,
+						iter_time=enc_config.iter_time,
 					)
 
 					enc_mods[part_mod] = luks_handler
@@ -333,10 +335,10 @@ class FilesystemHandler:
 				Size(256, Unit.MiB, SectorSize.default()),
 			)
 
-	def _final_warning(self, device_paths: str) -> bool:
+	def _final_warning(self) -> bool:
 		# Issue a final warning before we continue with something un-revertable.
 		# We mention the drive one last time, and count from 5 to 0.
-		out = tr(' ! Formatting {} in ').format(device_paths)
+		out = tr('Starting device modifications in ')
 		Tui.print(out, row=0, endl='', clear_screen=True)
 
 		try:
