@@ -6,8 +6,8 @@ from ..output import error
 def list_keyboard_languages() -> list[str]:
 	return (
 		SysCommand(
-			"localectl --no-pager list-keymaps",
-			environment_vars={"SYSTEMD_COLORS": "0"},
+			'localectl --no-pager list-keymaps',
+			environment_vars={'SYSTEMD_COLORS': '0'},
 		)
 		.decode()
 		.splitlines()
@@ -17,9 +17,9 @@ def list_keyboard_languages() -> list[str]:
 def list_locales() -> list[str]:
 	locales = []
 
-	with open("/usr/share/i18n/SUPPORTED") as file:
+	with open('/usr/share/i18n/SUPPORTED') as file:
 		for line in file:
-			if line != "C.UTF-8 UTF-8\n":
+			if line != 'C.UTF-8 UTF-8\n':
 				locales.append(line.rstrip())
 
 	return locales
@@ -28,8 +28,8 @@ def list_locales() -> list[str]:
 def list_x11_keyboard_languages() -> list[str]:
 	return (
 		SysCommand(
-			"localectl --no-pager list-x11-keymap-layouts",
-			environment_vars={"SYSTEMD_COLORS": "0"},
+			'localectl --no-pager list-x11-keymap-layouts',
+			environment_vars={'SYSTEMD_COLORS': '0'},
 		)
 		.decode()
 		.splitlines()
@@ -54,26 +54,26 @@ def get_kb_layout() -> str:
 	try:
 		lines = (
 			SysCommand(
-				"localectl --no-pager status",
-				environment_vars={"SYSTEMD_COLORS": "0"},
+				'localectl --no-pager status',
+				environment_vars={'SYSTEMD_COLORS': '0'},
 			)
 			.decode()
 			.splitlines()
 		)
 	except Exception:
-		return ""
+		return ''
 
-	vcline = ""
+	vcline = ''
 	for line in lines:
-		if "VC Keymap: " in line:
+		if 'VC Keymap: ' in line:
 			vcline = line
 
-	if vcline == "":
-		return ""
+	if vcline == '':
+		return ''
 
-	layout = vcline.split(": ")[1]
+	layout = vcline.split(': ')[1]
 	if not verify_keyboard_layout(layout):
-		return ""
+		return ''
 
 	return layout
 
@@ -81,11 +81,11 @@ def get_kb_layout() -> str:
 def set_kb_layout(locale: str) -> bool:
 	if len(locale.strip()):
 		if not verify_keyboard_layout(locale):
-			error(f"Invalid keyboard locale specified: {locale}")
+			error(f'Invalid keyboard locale specified: {locale}')
 			return False
 
 		try:
-			SysCommand(f"localectl set-keymap {locale}")
+			SysCommand(f'localectl set-keymap {locale}')
 		except SysCallError as err:
 			raise ServiceException(f"Unable to set locale '{locale}' for console: {err}")
 
@@ -97,8 +97,8 @@ def set_kb_layout(locale: str) -> bool:
 def list_timezones() -> list[str]:
 	return (
 		SysCommand(
-			"timedatectl --no-pager list-timezones",
-			environment_vars={"SYSTEMD_COLORS": "0"},
+			'timedatectl --no-pager list-timezones',
+			environment_vars={'SYSTEMD_COLORS': '0'},
 		)
 		.decode()
 		.splitlines()
