@@ -9,10 +9,10 @@ from archinstall.lib.translationhandler import tr
 
 
 class Repository(Enum):
-	Core = "core"
-	Extra = "extra"
-	Multilib = "multilib"
-	Testing = "testing"
+	Core = 'core'
+	Extra = 'extra'
+	Multilib = 'multilib'
+	Testing = 'testing'
 
 	def get_repository_list(self) -> list[str]:
 		match self:
@@ -24,9 +24,9 @@ class Repository(Enum):
 				return [Repository.Multilib.value]
 			case Repository.Testing:
 				return [
-					"core-testing",
-					"extra-testing",
-					"multilib-testing",
+					'core-testing',
+					'extra-testing',
+					'multilib-testing',
 				]
 
 
@@ -60,7 +60,7 @@ class PackageSearchResult:
 	checkdepends: list[str]
 
 	@staticmethod
-	def from_json(data: dict[str, Any]) -> "PackageSearchResult":
+	def from_json(data: dict[str, Any]) -> 'PackageSearchResult':
 		return PackageSearchResult(**data)
 
 	@property
@@ -74,7 +74,7 @@ class PackageSearchResult:
 
 		return self.pkg_version == other.pkg_version
 
-	def __lt__(self, other: "PackageSearchResult") -> bool:
+	def __lt__(self, other: 'PackageSearchResult') -> bool:
 		return self.pkg_version < other.pkg_version
 
 
@@ -88,42 +88,27 @@ class PackageSearch:
 	results: list[PackageSearchResult]
 
 	@staticmethod
-	def from_json(data: dict[str, Any]) -> "PackageSearch":
-		results = [PackageSearchResult.from_json(r) for r in data["results"]]
+	def from_json(data: dict[str, Any]) -> 'PackageSearch':
+		results = [PackageSearchResult.from_json(r) for r in data['results']]
 
 		return PackageSearch(
-			version=data["version"],
-			limit=data["limit"],
-			valid=data["valid"],
-			num_pages=data["num_pages"],
-			page=data["page"],
+			version=data['version'],
+			limit=data['limit'],
+			valid=data['valid'],
+			num_pages=data['num_pages'],
+			page=data['page'],
 			results=results,
 		)
 
 
 class LocalPackage(BaseModel):
 	name: str
-	repository: str
 	version: str
 	description: str
 	architecture: str
 	url: str
 	licenses: str
 	groups: str
-	depends_on: str
-	optional_deps: str
-	required_by: str
-	optional_for: str
-	conflicts_with: str
-	replaces: str
-	installed_size: str
-	packager: str
-	build_date: str
-	install_date: str
-	install_reason: str
-	install_script: str
-	validated_by: str
-	provides: str
 
 	@override
 	def __eq__(self, other: object) -> bool:
@@ -132,7 +117,7 @@ class LocalPackage(BaseModel):
 
 		return self.version == other.version
 
-	def __lt__(self, other: "LocalPackage") -> bool:
+	def __lt__(self, other: 'LocalPackage') -> bool:
 		return self.version < other.version
 
 
@@ -161,11 +146,11 @@ class AvailablePackage(BaseModel):
 
 	# return all package info line by line
 	def info(self) -> str:
-		output = ""
+		output = ''
 		for key, value in self.model_dump().items():
-			key = key.replace("_", " ").capitalize()
+			key = key.replace('_', ' ').capitalize()
 			key = key.ljust(self.longest_key)
-			output += f"{key} : {value}\n"
+			output += f'{key} : {value}\n'
 
 		return output
 
@@ -179,14 +164,14 @@ class PackageGroup:
 	def from_available_packages(
 		cls,
 		packages: dict[str, AvailablePackage],
-	) -> dict[str, "PackageGroup"]:
-		pkg_groups: dict[str, "PackageGroup"] = {}
+	) -> dict[str, 'PackageGroup']:
+		pkg_groups: dict[str, 'PackageGroup'] = {}
 
 		for pkg in packages.values():
-			if "None" in pkg.groups:
+			if 'None' in pkg.groups:
 				continue
 
-			groups = pkg.groups.split(" ")
+			groups = pkg.groups.split(' ')
 
 			for group in groups:
 				# same group names have multiple spaces in between
@@ -199,6 +184,6 @@ class PackageGroup:
 		return pkg_groups
 
 	def info(self) -> str:
-		output = tr("Package group:") + "\n  - "
-		output += "\n  - ".join(self.packages)
+		output = tr('Package group:') + '\n  - '
+		output += '\n  - '.join(self.packages)
 		return output
