@@ -13,7 +13,6 @@ from typing import Literal, override
 
 from archinstall.lib.translationhandler import tr
 
-from ..lib.output import debug
 from .help import Help
 from .menu_item import MenuItem, MenuItemGroup, MenuItemsState
 from .result import Result, ResultType
@@ -22,13 +21,13 @@ from .types import (
 	STYLE,
 	Alignment,
 	Chars,
+	FrameDim,
 	FrameProperties,
 	FrameStyle,
 	MenuKeys,
 	Orientation,
 	PreviewStyle,
 	ViewportEntry,
-	_FrameDim,
 )
 
 
@@ -83,14 +82,10 @@ class AbstractCurses[ValueT](metaclass=ABCMeta):
 
 			return False
 
-	def help_entry(self) -> ViewportEntry:
-		return ViewportEntry(tr('Press Ctrl+h for help'), 0, 0, STYLE.NORMAL)
+	def help_text(self) -> str:
+		return tr('Press Ctrl+h for help')
 
 	def _show_help(self) -> None:
-		if not self._help_window:
-			debug('no help window set')
-			return
-
 		help_text = Help.get_help_text()
 		lines = help_text.split('\n')
 
@@ -145,7 +140,7 @@ class AbstractViewport:
 
 		# adjust the original rows and cols of the entries as
 		# they need to be shrunk by 1 to make space for the frame
-		entries = self._adjust_entries(entries, dim)
+		entries = self._adjust_entries(entries)
 
 		framed_entries = [
 			top_ve,
@@ -163,7 +158,7 @@ class AbstractViewport:
 
 	def _get_right_frame(
 		self,
-		dim: _FrameDim,
+		dim: FrameDim,
 		scroll_percentage: int | None = None,
 	) -> list[ViewportEntry]:
 		right_frame = {}
@@ -186,7 +181,7 @@ class AbstractViewport:
 
 	def _get_top(
 		self,
-		dim: _FrameDim,
+		dim: FrameDim,
 		h_bar: str,
 		frame: FrameProperties,
 		scroll_percentage: int | None = None,
@@ -202,7 +197,7 @@ class AbstractViewport:
 
 	def _get_bottom(
 		self,
-		dim: _FrameDim,
+		dim: FrameDim,
 		h_bar: str,
 		scroll_pct: int | None = None,
 	) -> ViewportEntry:
@@ -219,7 +214,7 @@ class AbstractViewport:
 		max_width: int,
 		max_height: int,
 		frame: FrameProperties,
-	) -> _FrameDim:
+	) -> FrameDim:
 		rows = self._assemble_entries(entries).split('\n')
 		header_len = len(frame.header) if frame.header else 0
 		header_len += 3  # for header padding
@@ -242,12 +237,11 @@ class AbstractViewport:
 			frame_end = max_width
 			frame_height = max_height - 1
 
-		return _FrameDim(frame_start, frame_end, frame_height)
+		return FrameDim(frame_start, frame_end, frame_height)
 
 	def _adjust_entries(
 		self,
 		entries: list[ViewportEntry],
-		frame_dim: _FrameDim,
 	) -> list[ViewportEntry]:
 		for entry in entries:
 			# top row frame offset
@@ -293,7 +287,7 @@ class EditViewport(AbstractViewport):
 		edit_height: int,
 		x_start: int,
 		y_start: int,
-		process_key: Callable[[int], int | None],
+		process_key: Callable[[int], int],
 		frame: FrameProperties,
 		alignment: Alignment = Alignment.CENTER,
 		hide_input: bool = False,
@@ -361,6 +355,11 @@ class EditViewport(AbstractViewport):
 
 		self._main_win.refresh()
 
+	def textbox_value(self) -> str:
+		if not self._textbox:
+			return ''
+		return self._textbox.gather().strip()
+
 	def erase(self) -> None:
 		if self._main_win:
 			self._main_win.erase()
@@ -380,7 +379,7 @@ class EditViewport(AbstractViewport):
 			self._textbox = Textbox(self._edit_win)
 			self._main_win.refresh()
 
-		self._textbox.edit(self._process_key_cb)  # type: ignore[arg-type]
+		self._textbox.edit(self._process_key_cb)
 
 
 class Viewport(AbstractViewport):
@@ -390,7 +389,6 @@ class Viewport(AbstractViewport):
 		height: int,
 		x_start: int,
 		y_start: int,
-		enable_scroll: bool = False,
 		frame: FrameProperties | None = None,
 		alignment: Alignment = Alignment.LEFT,
 	):
@@ -400,7 +398,6 @@ class Viewport(AbstractViewport):
 		self.height = height
 		self.x_start = x_start
 		self.y_start = y_start
-		self._enable_scroll = enable_scroll
 		self._frame = frame
 		self._alignment = alignment
 
@@ -458,7 +455,7 @@ class EditMenu(AbstractCurses[str]):
 		title: str,
 		edit_width: int = 50,
 		header: str | None = None,
-		validator: Callable[[str], str | None] | None = None,
+		validator: Callable[[str | None], str | None] | None = None,
 		allow_skip: bool = False,
 		allow_reset: bool = False,
 		reset_warning_msg: str | None = None,
@@ -491,7 +488,7 @@ class EditMenu(AbstractCurses[str]):
 		title = f'* {title}' if not self._allow_skip else title
 		self._frame = FrameProperties(title, FrameStyle.MAX)
 
-		self._help_vp: Viewport | None = None
+		self._title_vp: Viewport | None = None
 		self._header_vp: Viewport | None = None
 		self._input_vp: EditViewport | None = None
 		self._info_vp: Viewport | None = None
@@ -503,12 +500,14 @@ class EditMenu(AbstractCurses[str]):
 
 		self._last_state: Result[str] | None = None
 		self._help_active = False
+
+		self._current_text = default_text or ''
 		self._real_input = default_text or ''
 
 	def _init_viewports(self) -> None:
 		y_offset = 0
 
-		self._help_vp = Viewport(self._max_width, 2, 0, y_offset)
+		self._title_vp = Viewport(self._max_width, 2, 0, y_offset)
 		y_offset += 2
 
 		if self._header_entries:
@@ -544,8 +543,8 @@ class EditMenu(AbstractCurses[str]):
 		self._draw()
 
 	def _clear_all(self) -> None:
-		if self._help_vp:
-			self._help_vp.erase()
+		if self._title_vp:
+			self._title_vp.erase()
 		if self._header_vp:
 			self._header_vp.erase()
 		if self._input_vp:
@@ -561,20 +560,25 @@ class EditMenu(AbstractCurses[str]):
 
 		self.clear_all()
 
-		if text and self._validator:
+		if self._validator:
 			if (err := self._validator(text)) is not None:
 				self.clear_all()
 				entry = ViewportEntry(err, 0, 0, STYLE.ERROR)
 				self._info_vp.update([entry], 0)
 				self._set_default_info = False
-				self._real_input = ''
+
+				if self._hide_input:
+					self._real_input = ''
+
 				return None
 
 		return text
 
 	def _draw(self) -> None:
-		if self._help_vp:
-			self._help_vp.update([self.help_entry()], 0)
+		if self._title_vp:
+			help_text = self.help_text()
+			help_entry = ViewportEntry(help_text, 0, 0, STYLE.NORMAL)
+			self._title_vp.update([help_entry], 0)
 
 		if self._header_entries and self._header_vp:
 			self._header_vp.update(self._header_entries, 0)
@@ -585,7 +589,7 @@ class EditMenu(AbstractCurses[str]):
 			if self._set_default_info and self._info_vp:
 				self._info_vp.update([self._only_ascii_text], 0)
 
-			self._input_vp.edit(default_text=self._default_text)
+			self._input_vp.edit(default_text=self._real_input)
 
 	@override
 	def kickoff(self, win: curses.window) -> Result[str]:
@@ -613,7 +617,7 @@ class EditMenu(AbstractCurses[str]):
 
 		return self._last_state
 
-	def _process_edit_key(self, key: int) -> int | None:
+	def _process_edit_key(self, key: int) -> int:
 		key_handles = MenuKeys.from_ord(key)
 
 		if self._help_active:
@@ -621,7 +625,7 @@ class EditMenu(AbstractCurses[str]):
 				self._help_active = False
 				self.clear_help_win()
 				return 7
-			return None
+			return 0
 
 		# remove standard keys from the list of key handles
 		key_handles = [key for key in key_handles if key != MenuKeys.STD_KEYS]
@@ -632,10 +636,12 @@ class EditMenu(AbstractCurses[str]):
 
 			match special_key:
 				case MenuKeys.HELP:
+					assert self._input_vp
+					self._current_text = self._input_vp.textbox_value()
 					self._clear_all()
 					self._help_active = True
 					self._show_help()
-					return None
+					return 0
 				case MenuKeys.ESC:
 					if self._allow_skip:
 						self._last_state = Result(ResultType.Skip, None)
@@ -691,6 +697,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		preview_style: PreviewStyle = PreviewStyle.NONE,
 		preview_size: float | Literal['auto'] = 0.2,
 		preview_frame: FrameProperties | None = None,
+		additional_title: str | None = None,
 	):
 		super().__init__()
 
@@ -711,11 +718,9 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		self._frame = frame
 		self._interrupt_warning = reset_warning_msg
 		self._header = header
+		self._additional_title = additional_title
 
-		# TODO: Remove the inline annotation after upgrading to mypy 1.16.0
-		# The inline annotation is needed to avoid a crash in 1.15.0:
-		#  RuntimeError: Partial type "<partial list[?]>" cannot be checked with "issubtype()"
-		self._header_entries: list[ViewportEntry] = []
+		self._header_entries = []
 		if header:
 			self._header_entries = self.get_header_entries(header)
 
@@ -732,7 +737,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		self._visible_entries: list[ViewportEntry] = []
 		self._max_height, self._max_width = Tui.t().max_yx
 
-		self._help_vp: Viewport | None = None
+		self._title_vp: Viewport | None = None
 		self._header_vp: Viewport | None = None
 		self._footer_vp: Viewport | None = None
 		self._menu_vp: Viewport | None = None
@@ -789,8 +794,8 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 			self._preview_vp.erase()
 		if self._footer_vp:
 			self._footer_vp.erase()
-		if self._help_vp:
-			self._help_vp.erase()
+		if self._title_vp:
+			self._title_vp.erase()
 
 	def _footer_entries(self) -> list[ViewportEntry]:
 		if self._active_search:
@@ -803,7 +808,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		footer_height = 2  # possible filter at the bottom
 		y_offset = 0
 
-		self._help_vp = Viewport(self._max_width, 2, 0, y_offset)
+		self._title_vp = Viewport(self._max_width, 2, 0, y_offset)
 		y_offset += 2
 
 		if self._header_entries:
@@ -935,8 +940,15 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		items = self._items_state.get_view_items()
 		vp_entries = self._item_to_vp_entry(items)
 
-		if self._help_vp:
-			self._update_viewport(self._help_vp, [self.help_entry()])
+		if self._title_vp:
+			title_text = self.help_text()
+
+			if self._additional_title is not None:
+				title_text += f' {self._additional_title}'
+
+			title_vp_entry = ViewportEntry(title_text, 0, 0, STYLE.NORMAL)
+
+			self._update_viewport(self._title_vp, [title_vp_entry])
 
 		if self._header_vp:
 			self._update_viewport(self._header_vp, self._header_entries)
@@ -1080,7 +1092,11 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 	) -> list[ViewportEntry]:
 		assert self._preview_vp is not None
 
-		start_row = self._prev_scroll_pos
+		if total_prev_rows <= available_rows:
+			start_row = 0
+		else:
+			start_row = self._prev_scroll_pos
+
 		end_row = start_row + available_rows
 
 		if end_row > total_prev_rows:
@@ -1231,7 +1247,7 @@ class Tui:
 			tui = self.init()
 			Tui._t = tui
 
-	def __exit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, tb: TracebackType | None) -> None:
+	def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
 		self.stop()
 
 	@property
@@ -1292,7 +1308,7 @@ class Tui:
 		text: str,
 		row: int = 0,
 		col: int = 0,
-		endl: str | None = '\n',
+		endl: str = '\n',
 		clear_screen: bool = False,
 	) -> None:
 		if clear_screen:
